Histograms in OpenCV.js {#tutorial_js_table_of_contents_histograms}
====================

-   @subpage tutorial_js_histogram_begins

    Learn the basics of histograms

-   @subpage tutorial_js_histogram_equalization

    Learn to Equalize Histograms to get better contrast for images

-   @subpage tutorial_js_histogram_backprojection

    Learn histogram backprojection to segment colored objects
